summaryrefslogtreecommitdiff
path: root/scripts/synth1.lua
diff options
context:
space:
mode:
authorJulien "_FrnchFrgg_" RIVAUD <frnchfrgg@free.fr>2016-08-04 17:47:38 +0200
committerJulien "_FrnchFrgg_" RIVAUD <frnchfrgg@free.fr>2016-08-06 19:38:09 +0200
commit66470b96b71571a0de34a9c4e64edff318211c30 (patch)
tree7a62f202ac814815f66c631fbba6a8e64f945db6 /scripts/synth1.lua
parent82e1ef5fb06ac37e3a719b03402fc2a4270e9625 (diff)
Remove dsp_has_midi_*() in favor of dsp_ioconfig()
_has_midi_*put members of LuaProc will be set according to the actual configuration chosen, for configure_io() and run() to use.
Diffstat (limited to 'scripts/synth1.lua')
-rw-r--r--scripts/synth1.lua17
1 files changed, 6 insertions, 11 deletions
diff --git a/scripts/synth1.lua b/scripts/synth1.lua
index 90da05d41e..2a8288ba52 100644
--- a/scripts/synth1.lua
+++ b/scripts/synth1.lua
@@ -10,20 +10,15 @@ ardour {
function dsp_ioconfig ()
return
{
- -- { audio_in = 0, audio_out = -1}, -- any number of channels
- -- { audio_in = 0, audio_out = 1}, -- values > 0, precisely N channels
- { audio_in = 0, audio_out = 2}, -- values > 0, precisely N channels
- { audio_in = 0, audio_out = 4}, -- values > 0, precisely N channels
- { audio_in = 0, audio_out = 8}, -- values > 0, precisely N channels
- -- { audio_in = 0, audio_out = -6}, -- values < -2, up to -N channels, here 1,..,6
+ -- { midi_in = 1, audio_in = 0, audio_out = -1}, -- any number of channels
+ -- { midi_in = 1, audio_in = 0, audio_out = 1}, -- values > 0, precisely N channels
+ { midi_in = 1, audio_in = 0, audio_out = 2}, -- values > 0, precisely N channels
+ { midi_in = 1, audio_in = 0, audio_out = 4}, -- values > 0, precisely N channels
+ { midi_in = 1, audio_in = 0, audio_out = 8}, -- values > 0, precisely N channels
+ -- { midi_in = 1, audio_in = 0, audio_out = -6}, -- values < -2, up to -N channels, here 1,..,6
}
end
-function dsp_has_midi_input ()
- return true
-end
-
-
local note_table = {}
local active_notes = {}
local phases = {}